==> cfg_e5_0_1_19_5_2_23.tar: cfg_e/js/js/tabs/thisDevice.js <==
let THIS_DEVICE = {}; // Карточка прибора

THIS_DEVICE.model = ''; // Модель 
THIS_DEVICE.sensors = []; // Шлейфы 
THIS_DEVICE.user = []; // Коды пользователей
THIS_DEVICE.rele = []; // Реле
THIS_DEVICE.gsmPhone = []; // GSM дозвон
THIS_DEVICE.encodeGK = []; // GK Ключ шифрации
THIS_DEVICE.XO = []; // Разделы

function pk4_init_key() {
    THIS_DEVICE.sensors = [];
    THIS_DEVICE.user = [];
    THIS_DEVICE.model = '';
    THIS_DEVICE.rele = [];
    THIS_DEVICE.gsmPhone = [];
    THIS_DEVICE.encodeGK = [];
    THIS_DEVICE.XO = [];

    //Поиск шлейфов
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key.indexOf("lm") != -1) {
            let thisShleif = {};
            thisShleif.number = deviceJSON.config[i].key.slice(2); // Номер ШС
            thisShleif.type = deviceJSON.config[i].subvalues[0].value; // Тип ШС
            thisShleif.delay = deviceJSON.config[i].subvalues[1].value; // Задержка ШС
            thisShleif.rl = false;

            let keyYz = 'yz' + thisShleif.number; // Название ключа YZ            
            if (dataDevice[keyYz]) {
                // Если в приборе новая прошивка с ключами YZ
                thisShleif.sections = dataDevice[keyYz].value; // Раздел в котором ШС
            } else {
                //Если в приборе старая прошивка с ключами ZN
                for (k in deviceJSON.config) {
                    if (deviceJSON.config[k].key.indexOf("zn") != -1) {
                        // Перебираем все разделы ZN
                        let sectionsZn = deviceJSON.config[k].subvalues[0] ? deviceJSON.config[k].subvalues[0].value.split(',') : []; // Преобразуем разделы в массив и проверяем на наличе значений subvalues
                        for (var z = 0; z < sectionsZn.length; z++) {
                            if (sectionsZn[z].charAt(0) == '0') sectionsZn[z] = sectionsZn[z].substring(1);
                            if (sectionsZn[z] === thisShleif.number) {
                                //Если номер раздела совпал с номером ШС записываем в ШС номер раздела
                                thisShleif.sections = deviceJSON.config[k].key.slice(2);
                            }
                        }
                    }
                }
            }

            let keyName = 'la' + thisShleif.number; // Название ключа псевдрнима ШС
            if (dataDevice[keyName]) {
                thisShleif.name = dataDevice[keyName].value; // Псевдоним ШС
            }

            THIS_DEVICE.sensors.push(thisShleif); // Сохраняем шлейф в базу

        } else if (deviceJSON.config[i].key.indexOf("lr") != -1) {
            // let thisShleif = {};
            // thisShleif.number = deviceJSON.config[i].key.slice(2); // Номер ШС
            // thisShleif.type = deviceJSON.config[i].subvalues[0].value; // Тип ШС
            // thisShleif.delay = deviceJSON.config[i].subvalues[1].value; // Задержка ШС
            // thisShleif.rl = true;

            // let keyYz = 'yz' + thisShleif.number; // Название ключа YZ            
            // if (dataDevice[keyYz]) {
            //     // Если в приборе новая прошивка с ключами YZ
            //     thisShleif.sections = dataDevice[keyYz].value; // Раздел в котором ШС
            // } else {
            //     //Если в приборе старая прошивка с ключами ZN
            //     for (k in deviceJSON.config) {
            //         if (deviceJSON.config[k].key.indexOf("zn") != -1) {
            //             // Перебираем все разделы ZN
            //             let sectionsZn = deviceJSON.config[k].subvalues[0] ? deviceJSON.config[k].subvalues[0].value.split(',') : []; // Преобразуем разделы в массив и проверяем на наличе значений subvalues
            //             for (var z = 0; z < sectionsZn.length; z++) {
            //                 if (sectionsZn[z] === thisShleif.number) {
            //                     //Если номер раздела совпал с номером ШС записываем в ШС номер раздела
            //                     thisShleif.sections = deviceJSON.config[k].key.slice(2);
            //                 }
            //             }
            //         }
            //     }
            // }

            // let keyName = 'la' + thisShleif.number; // Название ключа псевдрнима ШС
            // if (dataDevice[keyName]) {
            //     thisShleif.name = dataDevice[keyName].value; // Псевдоним ШС
            // }

            // THIS_DEVICE.sensors.push(thisShleif); // Сохраняем шлейф в базу
        } else if (deviceJSON.config[i].key.indexOf("ua") != -1) {
            if (deviceJSON.config[i].key !== 'ua') {
                if (deviceJSON.config[i].subvalues[2].value !== '') {
                    let thisUser = { "numberUser": null, "modeUser": null, "nameUser": null, "codeUser": null, "section": null };
                    thisUser.numberUser = deviceJSON.config[i].key.slice(2);
                    thisUser.modeUser = deviceJSON.config[i].subvalues[0].value; // Режим
                    thisUser.nameUser = deviceJSON.config[i].subvalues[1].value; // Псевдоним
                    thisUser.codeUser = deviceJSON.config[i].subvalues[2].value; // Код
                    thisUser.section = dataDevice["uz" + thisUser.numberUser] ? dataDevice["uz" + thisUser.numberUser].value : errorCore("uz" + thisUser.numberUser); // разделы

                    dataDevice["uz" + thisUser.numberUser] ? THIS_DEVICE.user.push(thisUser) : errorCore("uz" + thisUser.numberUser); //Сохраняем Юзера в базу
                }
            }
        } else if (deviceJSON.config[i].key.indexOf("rm") != -1) {
            if (deviceJSON.config[i].key === 'rm') {
                // Разбор ключей РЕЛЕ для ОО приборов
                let thisRele = { "number": '1', "mode": null, "time": null, "section": null, "key": null, "inline": true };
                thisRele.key = deviceJSON.config[i].key; // Название ключа
                thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
                thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
                thisRele.section = dataDevice['rz'] ? dataDevice['rz'].value : errorCore('rz');
                THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу    
            } else {
                // Разбор ключей РЕЛЕ для ППКОП приборов
                let thisRele = { "number": null, "mode": null, "time": null, "section": null, "key": null, "inline": true };
                thisRele.key = deviceJSON.config[i].key; // название ключа
                thisRele.number = deviceJSON.config[i].key.slice(2); // номер
                thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
                thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
                let rzKey = 'rz' + thisRele.number; // название ключа RZ привязки к разд.
                thisRele.section = dataDevice[rzKey] ? dataDevice[rzKey].value : errorCore(rzKey); // привязка к разделам
                THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу
                key_OC[thisRele.number] = thisRele;
            }

            // RZ привязка реле к разделу
        }
        //  else if (deviceJSON.config[i].key.indexOf("oo") != -1) {
        //     if (deviceJSON.config[i].subvalues[0].value !== '') {
        //         if (deviceJSON.config[i].key === 'oo') {
        //             // Разбор ключей РЕЛЕ для ОО приборов
        //             let thisRele = { "number": '1', "mode": null, "time": null, "section": null, "key": null, "inline": false };
        //             thisRele.key = deviceJSON.config[i].key; // Название ключа
        //             thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
        //             thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
        //             thisRele.section = dataDevice['oq'].value;
        //             THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу    
        //         } else {
        //             // Разбор ключей РЕЛЕ для ППКОП приборов
        //             let thisRele = { "number": null, "mode": null, "time": null, "section": null, "key": null, "inline": false };
        //             thisRele.key = deviceJSON.config[i].key; // название ключа
        //             thisRele.number = deviceJSON.config[i].key.slice(2); // номер
        //             thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
        //             thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
        //             let rzKey = 'oq' + thisRele.number; // название ключа RZ привязки к разд.
        //             thisRele.section = dataDevice[rzKey].value; // привязка к разделам
        //             THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу
        //         }
        //     }

        //     // RZ привязка реле к разделу
        // }
        else if (deviceJSON.config[i].key.indexOf("rb") != -1) {
            let firstNumberRele = parseInt(deviceJSON.config[i].subvalues[1].value);
            let endNumberRele = parseInt(deviceJSON.config[i].subvalues[0].value) + parseInt(deviceJSON.config[i].subvalues[1].value);

            for (var i = firstNumberRele; i < endNumberRele; i++) {
                if (i != 0) {
                    let ooType = 'oo' + i + '_0';
                    let ooTime = 'oo' + i + '_1';
                    ooType = dataDevice[ooType] && dataDevice[ooType].value;
                    ooTime = dataDevice[ooTime] && dataDevice[ooTime].value;

                    let thisRele = { "number": null, "mode": null, "time": null, "section": null, "key": null, "inline": false };
                    thisRele.key = 'oo' + i; // название ключа
                    thisRele.number = i + ''; // номер
                    thisRele.mode = ooType; // Режим;
                    thisRele.time = ooTime; // Время работы;
                    let rzKey = 'oq' + thisRele.number; // название ключа RZ привязки к разд.
                    thisRele.section = dataDevice[rzKey].value; // привязка к разделам
                    THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу
                    key_OC[thisRele.number] = thisRele;
                }
            }

        }
        else if (deviceJSON.config[i].key.indexOf("dn") != -1) {
            let thisGSM = { "number": null, "phone": null, "mode": null };
            thisGSM.number = deviceJSON.config[i].key.slice(2); // Номер ключа
            thisGSM.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
            thisGSM.phone = deviceJSON.config[i].subvalues[1].value; // телефон

            THIS_DEVICE.gsmPhone.push(thisGSM); //Сохраняем телефон с режимом в базу

        } else if (deviceJSON.config[i].key.indexOf("lc") != -1) {
            document.getElementById('tab_sensors_pk4_lc').innerHTML = listFixedSensors(deviceJSON.config[i].subvalues[0].value);

        } else if (deviceJSON.config[i].key.indexOf("gk") != -1) {
            let code = { "number": null, "code": null };
            code.number = deviceJSON.config[i].key.slice(2);
            code.code = deviceJSON.config[i].subvalues[0].value;
            THIS_DEVICE.encodeGK.push(code);

        } else if (deviceJSON.config[i].key.indexOf("xo") != -1) {
            if (deviceJSON.config[i].key !== 'xo') {

                let thisXO = { "delay": null, "number": null };
                thisXO.number = deviceJSON.config[i].key.slice(2);
                thisXO.delay = deviceJSON.config[i].subvalues[0].value;
                THIS_DEVICE.XO.push(thisXO); //Сохраняем раздел в базу

            }
        } else if (deviceJSON.config[i].key.indexOf("td") != -1) {
            THIS_DEVICE.model = deviceJSON.config[i].subvalues[0].value; //Модель прибора
        }
    }


}

==> cfg_e3008_310.tar: cfg_e/js/js/tabs/thisDevice.js <==
let THIS_DEVICE = {}; // Карточка прибора

THIS_DEVICE.model = ''; // Модель 
THIS_DEVICE.sensors = []; // Шлейфы 
THIS_DEVICE.user = []; // Коды пользователей
THIS_DEVICE.rele = []; // Реле
THIS_DEVICE.gsmPhone = []; // GSM дозвон
THIS_DEVICE.encodeGK = []; // GK Ключ шифрации
THIS_DEVICE.XO = []; // Разделы

function pk4_init_key() {
    THIS_DEVICE.sensors = [];
    THIS_DEVICE.user = [];
    THIS_DEVICE.model = '';
    THIS_DEVICE.rele = [];
    THIS_DEVICE.gsmPhone = [];
    THIS_DEVICE.encodeGK = [];
    THIS_DEVICE.XO = [];

    //Поиск шлейфов
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key.indexOf("lm") != -1) {
            let thisShleif = {};
            thisShleif.number = deviceJSON.config[i].key.slice(2); // Номер ШС
            thisShleif.type = deviceJSON.config[i].subvalues[0].value; // Тип ШС
            thisShleif.delay = deviceJSON.config[i].subvalues[1].value; // Задержка ШС
            thisShleif.rl = false;

            let keyYz = 'yz' + thisShleif.number; // Название ключа YZ            
            if (keyForParse[keyYz]) {
                // Если в приборе новая прошивка с ключами YZ
                thisShleif.sections = keyForParse[keyYz].value; // Раздел в котором ШС
            } else {
                //Если в приборе старая прошивка с ключами ZN
                for (k in deviceJSON.config) {
                    if (deviceJSON.config[k].key.indexOf("zn") != -1) {
                        // Перебираем все разделы ZN
                        let sectionsZn = deviceJSON.config[k].subvalues[0] ? deviceJSON.config[k].subvalues[0].value.split(',') : []; // Преобразуем разделы в массив и проверяем на наличе значений subvalues
                        for (var z = 0; z < sectionsZn.length; z++) {
                            if (sectionsZn[z].charAt(0) == '0') sectionsZn[z] = sectionsZn[z].substring(1);
                            if (sectionsZn[z] === thisShleif.number) {
                                //Если номер раздела совпал с номером ШС записываем в ШС номер раздела
                                thisShleif.sections = deviceJSON.config[k].key.slice(2);
                            }
                        }
                    }
                }
            }

            let keyName = 'la' + thisShleif.number; // Название ключа псевдрнима ШС
            if (keyForParse[keyName]) {
                thisShleif.name = keyForParse[keyName].value; // Псевдоним ШС
            }

            THIS_DEVICE.sensors.push(thisShleif); // Сохраняем шлейф в базу

        } else if (deviceJSON.config[i].key.indexOf("lr") != -1) {
            // let thisShleif = {};
            // thisShleif.number = deviceJSON.config[i].key.slice(2); // Номер ШС
            // thisShleif.type = deviceJSON.config[i].subvalues[0].value; // Тип ШС
            // thisShleif.delay = deviceJSON.config[i].subvalues[1].value; // Задержка ШС
            // thisShleif.rl = true;

            // let keyYz = 'yz' + thisShleif.number; // Название ключа YZ            
            // if (keyForParse[keyYz]) {
            //     // Если в приборе новая прошивка с ключами YZ
            //     thisShleif.sections = keyForParse[keyYz].value; // Раздел в котором ШС
            // } else {
            //     //Если в приборе старая прошивка с ключами ZN
            //     for (k in deviceJSON.config) {
            //         if (deviceJSON.config[k].key.indexOf("zn") != -1) {
            //             // Перебираем все разделы ZN
            //             let sectionsZn = deviceJSON.config[k].subvalues[0] ? deviceJSON.config[k].subvalues[0].value.split(',') : []; // Преобразуем разделы в массив и проверяем на наличе значений subvalues
            //             for (var z = 0; z < sectionsZn.length; z++) {
            //                 if (sectionsZn[z] === thisShleif.number) {
            //                     //Если номер раздела совпал с номером ШС записываем в ШС номер раздела
            //                     thisShleif.sections = deviceJSON.config[k].key.slice(2);
            //                 }
            //             }
            //         }
            //     }
            // }

            // let keyName = 'la' + thisShleif.number; // Название ключа псевдрнима ШС
            // if (keyForParse[keyName]) {
            //     thisShleif.name = keyForParse[keyName].value; // Псевдоним ШС
            // }

            // THIS_DEVICE.sensors.push(thisShleif); // Сохраняем шлейф в базу
        } else if (deviceJSON.config[i].key.indexOf("ua") != -1) {
            if (deviceJSON.config[i].key !== 'ua') {
                if (deviceJSON.config[i].subvalues[2].value !== '') {
                    let thisUser = { "numberUser": null, "modeUser": null, "nameUser": null, "codeUser": null, "section": null };
                    thisUser.numberUser = deviceJSON.config[i].key.slice(2);
                    thisUser.modeUser = deviceJSON.config[i].subvalues[0].value; // Режим
                    thisUser.nameUser = deviceJSON.config[i].subvalues[1].value; // Псевдоним
                    thisUser.codeUser = deviceJSON.config[i].subvalues[2].value; // Код
                    thisUser.section = keyForParse["uz" + thisUser.numberUser] ? keyForParse["uz" + thisUser.numberUser].value : errorCore("uz" + thisUser.numberUser); // разделы

                    keyForParse["uz" + thisUser.numberUser] ? THIS_DEVICE.user.push(thisUser) : errorCore("uz" + thisUser.numberUser); //Сохраняем Юзера в базу
                }
            }
        } else if (deviceJSON.config[i].key.indexOf("rm") != -1) {
            if (deviceJSON.config[i].key === 'rm') {
                // Разбор ключей РЕЛЕ для ОО приборов
                let thisRele = { "number": '1', "mode": null, "time": null, "section": null, "key": null, "inline": true };
                thisRele.key = deviceJSON.config[i].key; // Название ключа
                thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
                thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
                thisRele.section = keyForParse['rz'] ? keyForParse['rz'].value : errorCore('rz');
                THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу    
            } else {
                // Разбор ключей РЕЛЕ для ППКОП приборов
                let thisRele = { "number": null, "mode": null, "time": null, "section": null, "key": null, "inline": true };
                thisRele.key = deviceJSON.config[i].key; // название ключа
                thisRele.number = deviceJSON.config[i].key.slice(2); // номер
                thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
                thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
                let rzKey = 'rz' + thisRele.number; // название ключа RZ привязки к разд.
                thisRele.section = keyForParse[rzKey] ? keyForParse[rzKey].value : errorCore(rzKey); // привязка к разделам
                THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу
                key_OC[thisRele.number] = thisRele;
            }

            // RZ привязка реле к разделу
        }
        //  else if (deviceJSON.config[i].key.indexOf("oo") != -1) {
        //     if (deviceJSON.config[i].subvalues[0].value !== '') {
        //         if (deviceJSON.config[i].key === 'oo') {
        //             // Разбор ключей РЕЛЕ для ОО приборов
        //             let thisRele = { "number": '1', "mode": null, "time": null, "section": null, "key": null, "inline": false };
        //             thisRele.key = deviceJSON.config[i].key; // Название ключа
        //             thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
        //             thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
        //             thisRele.section = keyForParse['oq'].value;
        //             THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу    
        //         } else {
        //             // Разбор ключей РЕЛЕ для ППКОП приборов
        //             let thisRele = { "number": null, "mode": null, "time": null, "section": null, "key": null, "inline": false };
        //             thisRele.key = deviceJSON.config[i].key; // название ключа
        //             thisRele.number = deviceJSON.config[i].key.slice(2); // номер
        //             thisRele.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
        //             thisRele.time = deviceJSON.config[i].subvalues[1].value; // Режим;
        //             let rzKey = 'oq' + thisRele.number; // название ключа RZ привязки к разд.
        //             thisRele.section = keyForParse[rzKey].value; // привязка к разделам
        //             THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу
        //         }
        //     }

        //     // RZ привязка реле к разделу
        // }
        else if (deviceJSON.config[i].key.indexOf("rb") != -1) {
            let firstNumberRele = parseInt(deviceJSON.config[i].subvalues[1].value);
            let endNumberRele = parseInt(deviceJSON.config[i].subvalues[0].value) + parseInt(deviceJSON.config[i].subvalues[1].value);

            for (var i = firstNumberRele; i < endNumberRele; i++) {
                if (i != 0) {
                    let ooType = 'oo' + i + '_0';
                    let ooTime = 'oo' + i + '_1';
                    ooType = keyForParse[ooType].value;
                    ooTime = keyForParse[ooTime].value;

                    let thisRele = { "number": null, "mode": null, "time": null, "section": null, "key": null, "inline": false };
                    thisRele.key = 'oo' + i; // название ключа
                    thisRele.number = i + ''; // номер
                    thisRele.mode = ooType; // Режим;
                    thisRele.time = ooTime; // Время работы;
                    let rzKey = 'oq' + thisRele.number; // название ключа RZ привязки к разд.
                    thisRele.section = keyForParse[rzKey].value; // привязка к разделам
                    THIS_DEVICE.rele.push(thisRele); //Сохраняем РЕЛЕ в базу
                    key_OC[thisRele.number] = thisRele;
                }
            }

        }
        else if (deviceJSON.config[i].key.indexOf("dn") != -1) {
            let thisGSM = { "number": null, "phone": null, "mode": null };
            thisGSM.number = deviceJSON.config[i].key.slice(2); // Номер ключа
            thisGSM.mode = deviceJSON.config[i].subvalues[0].value; // Режим;
            thisGSM.phone = deviceJSON.config[i].subvalues[1].value; // телефон

            THIS_DEVICE.gsmPhone.push(thisGSM); //Сохраняем телефон с режимом в базу

        } else if (deviceJSON.config[i].key.indexOf("lc") != -1) {
            document.getElementById('tab_sensors_pk4_lc').innerHTML = listFixedSensors(deviceJSON.config[i].subvalues[0].value);

        } else if (deviceJSON.config[i].key.indexOf("gk") != -1) {
            let code = { "number": null, "code": null };
            code.number = deviceJSON.config[i].key.slice(2);
            code.code = deviceJSON.config[i].subvalues[0].value;
            THIS_DEVICE.encodeGK.push(code);

        } else if (deviceJSON.config[i].key.indexOf("xo") != -1) {
            if (deviceJSON.config[i].key !== 'xo') {

                let thisXO = { "delay": null, "number": null };
                thisXO.number = deviceJSON.config[i].key.slice(2);
                thisXO.delay = deviceJSON.config[i].subvalues[0].value;
                THIS_DEVICE.XO.push(thisXO); //Сохраняем раздел в базу

            }
        } else if (deviceJSON.config[i].key.indexOf("td") != -1) {
            THIS_DEVICE.model = deviceJSON.config[i].subvalues[0].value; //Модель прибора
        }
    }


}
